@@ -854,10 +854,10 @@ gff_load (GnomeFontFace *face)
 	FT_Error ft_result;
 	static FT_Library ft_library = NULL;
 	GPFontEntry *entry;
-	FT_CharMap found = 0;
+	FT_CharMap found = NULL;
 	FT_CharMap charmap;
-	FT_CharMap appleRoman = 0;
-	FT_CharMap symbol = 0;
+	FT_CharMap appleRoman = NULL;
+	FT_CharMap symbol = NULL;
 	const guchar *psname;
 	int n;
 
@@ -1087,7 +1087,7 @@ static int gfft2_cubic_to (FT_Vector * control1, FT_Vector * control2, FT_Vector
 	return 0;
 }
 
-FT_Outline_Funcs gfft2_outline_funcs = {
+static FT_Outline_Funcs gfft2_outline_funcs = {
 	gfft2_move_to,
 	gfft2_line_to,
 	gfft2_conic_to,
